import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { SERVER_API_URL } from 'app/app.constants';
import { GitlabGroup } from 'app/shared/model/gitlab-group.model';
import { Observable } from 'rxjs';

@Injectable({
  providedIn: 'root',
})
export class GitlabService {
  public resourceUrl = SERVER_API_URL + 'api/gitlab/';

  constructor(private http: HttpClient) {}

  /**
   * Used to retrieve all groups of current user
   * (As user: their groups, as admin: all groups)
   */
  public getGroups(): Observable<Array<GitlabGroup>> {
    return this.http.get<Array<GitlabGroup>>(`${this.resourceUrl}groups`);
  }

  /**
   * used to retrieve subgroups of a given Gitlab group
   * @param group to retrieve its subgroups
   */
  public getSubGroups(group: GitlabGroup): Observable<Array<GitlabGroup>> {
    return this.http.get<Array<GitlabGroup>>(`${this.resourceUrl}subgroups/${group.id}`);
  }
}
